prompt property
String
get
prompt
By default the login screen is displayed if the user is not logged into
Keycloak. To only authenticate to the application if the user is already
logged in and not display the login page if the user is not logged in, set
this option to 'none'. To always require re-authentication and ignore
SSO, set this option to 'login'.
Implementation
external String /*'none'|'login'*/ get prompt;
set
prompt
(String v)
Implementation
external set prompt(String /*'none'|'login'*/ v);