scope property

String get scope

Specifies the scope parameter for the login url The scope 'openid' will be added to the scope if it is missing or undefined.

Implementation

external String get scope;
set scope (String v)

Implementation

external set scope(String v);